package Drawnings;

import java.awt.*;
import Entities.*;
import MovementStrategy.*;

public class DrawingAirbus {

    public EntityAirbus entityAirbus;
    public DrawingPortholes _portholes;
    private int _pictureWidth;
    private int _pictureHeight;
    private int _startPosX;
    private int _startPosY;
    private int _airbusWidth = 123;
    private int _airbusHeight = 44;

    public void Init(int speed, float weight, Color bodyColor, Color additionalColor, boolean isCompartment, boolean isadditionalEngine, int countPortholes, int width, int height) {
        if (width < _airbusHeight || height < _airbusWidth)
            return;
        _pictureWidth = width;
        _pictureHeight = height;
        entityAirbus = new EntityAirbus();
        entityAirbus.Init(speed, weight, bodyColor, additionalColor, isCompartment, isadditionalEngine);

        _portholes = new DrawingPortholes();
        _portholes.SetCount(countPortholes);
    }

    public void SetPosition (int x, int y) {
        if (x + _airbusWidth > _pictureWidth || y + _airbusHeight > _pictureHeight) {
            _startPosX = _pictureWidth - _airbusWidth;
            _startPosY = _pictureHeight - _airbusHeight;
        }
        else
        {
            _startPosX = x;
            _startPosY = y;
        }
    }

    public void MoveTransport(Direction direction){
        if (entityAirbus == null) {
            return;
        }

        switch (direction) {
            case Left:
            if (_startPosX - entityAirbus.Step > 0)
            {
                _startPosX -= entityAirbus.Step;
            }
            break;
        case Right:
            if (_startPosX + _airbusWidth + entityAirbus.Step < _pictureWidth)
            {
                _startPosX += entityAirbus.Step;
            }
            break;
        case Up:
            if (_startPosY - entityAirbus.Step > 0)
            {
                _startPosY -= entityAirbus.Step;
            }
            break;
        case Down:
            if (_startPosY + _airbusHeight + entityAirbus.Step < _pictureHeight)
            {
                _startPosY += entityAirbus.Step;
            }
            break;
        }
    }

    public void DrawTransport(Graphics2D g) {

        if (entityAirbus == null) {
            return;
        }
        // тело
        g.setColor(entityAirbus.getBodyColor());
        g.fillRect(_startPosX+3, _startPosY+17, 103, 20);
        g.setColor(Color.BLACK);
        g.drawRect(_startPosX+3, _startPosY+17, 103, 20);

        // иллюминаторы
        _portholes.Draw(g, _startPosX, _startPosY);

        // нос
        int[] xPolygonNoise = {_startPosX+106, _startPosX + 120, _startPosX+106,};
        int[] yPolygonNoise = {_startPosY+17, _startPosY+27, _startPosY+37};

        g.setColor(entityAirbus.getBodyColor());
        g.fillPolygon(xPolygonNoise, yPolygonNoise, xPolygonNoise.length);
        g.setColor(Color.BLACK);
        g.drawPolygon(xPolygonNoise, yPolygonNoise, xPolygonNoise.length);

        // хвост
        int[] xPolygonTale = { _startPosX+2, _startPosX+27, _startPosX+2};
        int[] yPolygonTale = {_startPosY, _startPosY + 18,_startPosY+18};
        g.setColor(entityAirbus.getBodyColor());
        g.fillPolygon(xPolygonTale, yPolygonTale, xPolygonTale.length);
        g.setColor(Color.BLACK);
        g.drawPolygon(xPolygonTale, yPolygonTale, xPolygonTale.length);

        // крыло
        g.setColor(Color.BLACK);
        g.fillOval(_startPosX+43, _startPosY+25, 22, 5);
        g.drawOval(_startPosX+43, _startPosY+25, 22, 5);

        // двигатель
        g.setColor(Color.BLACK);
        g.fillOval(_startPosX+1, _startPosY+15, 19, 5);
        g.drawOval(_startPosX+1, _startPosY+15, 19, 5);

        // шасси
        g.setColor(entityAirbus.getBodyColor());
        g.fillOval(_startPosX+25,_startPosY+38, 6, 6);
        g.fillOval(_startPosX+30,_startPosY+38, 6, 6);
        g.fillOval(_startPosX+100,_startPosY+38, 6, 6);
        g.setColor(Color.BLACK);
        g.drawOval(_startPosX+25,_startPosY+38, 6, 6);
        g.drawOval(_startPosX+30,_startPosY+38, 6, 6);
        g.drawOval(_startPosX+100,_startPosY+38, 6, 6);

        // пассажирский отсек
        if (entityAirbus.IsCompartment())
        {
            g.setColor(entityAirbus.getAdditionalColor());
            g.fillOval(_startPosX+57, _startPosY+11, 39, 9);
            g.setColor(Color.BLACK);
            g.drawOval(_startPosX+57, _startPosY+11, 39, 9);
        }

        // доп двигатель
        if (entityAirbus.IsAdditionalEngine())
        {
            g.setColor(entityAirbus.getAdditionalColor());
            g.fillOval(_startPosX, _startPosY + 25, 11, 5);
            g.setColor(Color.BLACK);
            g.drawOval(_startPosX, _startPosY + 25, 11, 5);
        }
    }
}
